//
//	"$Id: Icon.h The Dec 28 2006 Dmitry Perov  $"
//
//	Icon for the Fast Light Tool Kit (FLTK2).
//
//   Copyright 1998-2006 by Bill Spitzak and others.
//
//
//   This program is free software; you can redistribute it and/or modify
//   it under the terms of the GNU General Public License as published by
//   the Free Software Foundation; either version 2 of the License, or
//   (at your option) any later version.
//
//   This program is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//   GNU General Public License for more details.
//
//   You should have received a copy of the GNU General Public License
//   along with this program; if not, write to the
//   Free Software Foundation, Inc.,
//   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
//	Please report all bugs and problems to "gentooshnik@rambler.ru"
//

#ifndef Icon_h
#define Icon_h

#include <fltk/Window.h>

/**

Thanks Bill Spitzak, matthiasm, Greg Ercolano, and all peoples
albeit somehow cohere per developers FLTK

*/

#if defined(__linux) /** Linux */

#include <fltk/x11.h>


/** set the icon from xbm bits  */

extern void set_icon(fltk::Window* main, const char* xbm_bits, const char* icon_name, int xbm_w, int xbm_h)
{

if( !main ){ return; }
else if( !main->shown() ){ main->show(); }

Pixmap icon_pixmap = XCreateBitmapFromData(fltk::xdisplay, DefaultRootWindow(fltk::xdisplay), xbm_bits, xbm_w, xbm_h);

XSetStandardProperties(fltk::xdisplay, fltk::xid(main), NULL, icon_name, icon_pixmap, NULL, 0, 0);

}



/** Author: Greg Ercolano <erco@3dsite.com> [] */

/** Compile your programs with LDFLAGS="$LDFLAGS -lXpm" */

/** set the icon from Xpm char ** data  */

#include <X11/xpm.h>

extern void set_icon(fltk::Window* main, char ** xpm_data)
{

if( !main ){ return; }
else if( !main->shown() ){ main->show(); }

Pixmap icon_pixmap;
Pixmap icon_mask;

int isXpm = XpmCreatePixmapFromData(fltk::xdisplay, DefaultRootWindow(fltk::xdisplay), xpm_data, &icon_pixmap, &icon_mask, NULL );

if(isXpm != XpmSuccess){ return; }

XWMHints hints;

hints.flags = IconPixmapHint | IconMaskHint;
hints.icon_pixmap = icon_pixmap;
hints.icon_mask = icon_mask;

XSetWMHints (fltk::xdisplay, fltk::xid(main), &hints);

}



#elif defined(_WIN32) /** Windows */

#include <fltk/win32.h>

/** Author: alexander.stoyan alexander.stoyan@gmail.com [http://forum.sources.ru] */

/** set the icon from *.ico files */

extern void set_icon(fltk::Window* main, char * file_icon)
{

if( !main ){ return; }
else if( !main->shown() ){ main->show(); }

HWND hw = fltk::xid(main);

HICON hIcon = (HICON)LoadImage(NULL, file_icon, IMAGE_ICON, LR_DEFAULTSIZE, LR_DEFAULTSIZE, LR_LOADFROMFILE);

if(hIcon)
{
     SendMessage (hw, WM_SETICON, ICON_BIG, (LPARAM) hIcon);
     SendMessage (hw, WM_SETICON, ICON_SMALL, (LPARAM) hIcon);

     // or
     // SetClassLong(hw,GCL_HICON,(long)(LONG_PTR)hIcon);
     // SetClassLong(hw,GCL_HICONSM,(long)(LONG_PTR)hIcon);

     hIcon = NULL;
}

}


#endif

#endif

//
// End of  "$Id: Icon.h The Dec 28 2006 Dmitry Perov  $".
//
